==> gridx-1.3-javadoc.jar: nls/uk/gridx.js <==
define({     
//Body
	loadingInfo: "Завантаження...",
	emptyInfo: "Немає елементів для відображення",
	loadFailInfo: "Не вдалося завантажити оновлення",
	loadMore: "Завантажити ще",
	loadMoreLoading: "Завантаження...",
	loadPrevious: "Завантажити попередні",
	loadPreviousLoading: "Завантаження...",

//FilterBar
	"clearFilterDialogTitle": "Очистити фільтр",
	"filterDefDialogTitle": "Фільтр",
	"defaultRuleTitle": "Правило",
	"ruleTitleTemplate": "Правило ${ruleNumber}",
	"noFilterApplied": "Фільтри не використовуються.",
	"defineFilter": "Визначити фільтр",
	"conditionEqual": "дорівнює",
	"conditionNotEqual": "не дорівнює",
	"conditionLess": "менше за",
	"conditionLessEqual": "менше або дорівнює",
	"conditionGreater": "більше за",
	"conditionGreaterEqual": "більше або дорівнює",
	"conditionContain": "містить",
	"conditionIs": "дорівнює",
	"conditionStartWith": "починається з",
	"conditionEndWith": "закінчується на",
	"conditionNotContain": "не містить",
	"conditionIsNot": "не дорівнює",
	"conditionNotStartWith": "не починається з",
	"conditionNotEndWith": "не закінчується на",
	"conditionBefore": "до",
	"conditionAfter": "після",
	"conditionRange": "діапазон",
	"conditionIsEmpty": "порожній",
	"all": "всі",
	"any": "будь-яке",
	"relationAll": "всі правила",
	"waiRelAll": "Відповідає всім наступним правилам:",
	"relationAny": "Будь-яке правило",
	"waiRelAny": "Відповідає будь-якому з наступних правил:",
	"relationMsgFront": "Відповідає",
	"relationMsgTail": "",
	"and": "та",
	"or": "або",
	"addRuleButton": "Додати правило",
	"waiAddRuleButton": "Додати нове правило",
	"removeRuleButton": "Видалити правило",
	"waiRemoveRuleButtonTemplate": "Видалити правило ${0}",
	"addRuleButton": "Додати правило фільтрації",
	"cancelButton": "Скасувати",
	"waiCancelButton": "Скасувати це вікно",
	"clearButton": "Очистити",
	"waiClearButton": "Очистити фільтр",
	"filterButton": "Фільтр",
	"waiFilterButton": "Застосувати фільтр",
	"columnSelectLabel": "Стовпець:",
	"waiColumnSelectTemplate": "Стовпчик для правила ${0}",
	"conditionSelectLabel": "Умова:",
	"waiConditionSelectTemplate": "Умова правила ${0}",
	"valueBoxLabel": "Значення:",
	"waiValueBoxTemplate": "Введіть значення для фільтрації за правилом ${0}",
	"rangeTo": "до",
	"rangeTemplate": "з ${0} до ${1}",
	"statusTipHeaderColumn": "Стовпчик",
	"statusTipHeaderCondition": "Правила",
	"statusTipTitle": "Панель фільтрів",
	"statusTipMsg": "Клацніть на панелі фільтрів для фільтрації за значеннями у ${0}.",
	"anycolumn": "будь-який стовпець",
	"statusTipTitleNoFilter": "Панель фільтрів",
	"statusTipTitleHasFilter": "Фільтр",
	"statusTipRelPre": "Відповідає",
	"statusTipRelPost": "правила.",
	"statusTipHeaderAll": "Відповідає всім правилам.",
	"statusTipHeaderAny": "Відповідає хоча б одному правилу.",
	"defaultItemsName": "елементи",
	"filterBarMsgHasFilterTemplate": "Показано ${0} з ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Фільтр не використовується",
	"filterBarDefButton": "Визначити фільтр",
	"waiFilterBarDefButton": "Фільтрувати таблицю",
	"a11yFilterBarDefButton": "Фільтр...",
	"filterBarClearButton": "Очистити фільтр",
	"waiFilterBarClearButton": "Очистити фільтр",
	"closeFilterBarBtn": "Закрити панель фільтрів",
	"clearFilterMsg": "Ця опція видаляє фільтр та показує всі доступні записи.",
	"anyColumnOption": "Будь-який стовпець",
	"trueLabel": "Істина",
	"falseLabel": "Неправда",
	"radioTrueLabel": "Значення True",
	"radioFalseLabel": "Значення False",
	"beginTimeRangeLabel": "Початкове значення диапазону часу",
	"endTimeRangeLabel": "Кінцеве значення диапазону часу",
	"beginDateRangeLabel": "Початкове значення диапазону дат",
	"endDateRangeLabel": "Кінцеве значення диапазону дат",
	"startsWithExpr": "${0}*",

//NestedSort
	singleSort: "Однорівневе сортування",
	nestedSort: "Вкладене сортування",
	ascending: "Клацніть для сортування за зростанням",
	descending: "Клацніть для сортування за спаданням",
	sortingState: "${0} - ${1}",
	unsorted: "Не сортувати цей стовпець",
	waiSingleSortLabel: "${0} - відсортовано за ${1}. Виберіть для сортування за ${2}",
	waiNestedSortLabel:"${0} - вкладене сортування за ${1}. Виберіть для вкладеного сортування за ${2}",

//PaginationBar
	pagerWai: 'Пейджер',

	pageIndex: '${0}',
	pageIndexTitle: 'Сторінка ${0}',

	firstPageTitle: 'Перша сторінка',
	prevPageTitle: 'Попередня сторінка',
	nextPageTitle: 'Наступна сторінка',
	lastPageTitle: 'Остання сторінка',

	pageSize: '${0}',
	pageSizeTitle: '${0} елементів на сторінці',
	pageSizeAll: 'Всі',
	pageSizeAllTitle: 'Усі елементи',

	description: '${0} - ${1} з ${2} елементів.',
	descriptionEmpty: 'Матриця порожня.',

	summary: 'Всього: ${0}',
	summaryWithSelection: 'Всього: ${0} Вибрано: ${1}',

	gotoBtnTitle: 'Перейти до вказаної сторінки',

	gotoDialogTitle: 'Перейти до сторінки',
	gotoDialogMainMsg: 'Вкажіть номер сторінки:',
	gotoDialogPageCount: '(${0} сторінок)',
	gotoDialogOKBtn: 'Перейти',
	gotoDialogCancelBtn: 'Скасувати',
	// for drop down pagination bar
	pageLabel: 'Сторінка',
	pageSizeLabel: 'Рядки',

//QuickFilter
	filterLabel: 'Фільтр',
	clearButtonTitle: 'Очистити фільтр',
	buildFilterMenuLabel: 'Скласти фільтр&hellip;',
	apply: 'Застосувати фільтр',

//Sort
	helpMsg: '${0} - Клацніть для сортування або клацніть, утримуючи клавішу Control, для додання до списку сортування',
	singleHelpMsg: '${0} - Клацніть для сортування',
	priorityOrder: 'Пріоритет сортування ${0}',

//SummaryBar
	summaryTotal: 'Всього: ${0}',
	summarySelected: 'Виділено: ${0}',
	summaryRange: 'Діапазон: ${0}-${1}',	//need translation

//Other
	indirectSelectAll: "Натисніть SPACE, щоб вибрати всі.",	//need translation
	indirectDeselectAll: "Натисніть SPACE, щоб скасувати вибір всіх.",	//need translation
	treeExpanded: "Натисніть Control + стрілка вліво для згортання рядка.",	//need translation
	treeCollapsed: "Натисніть Control + стрілка вправо для розгортання рядка."	//need translation
});

==> gridx-1.3.9-javadoc.jar: nls/uk/gridx.js <==
define({     
//Body
	loadingInfo: "Завантаження...",
	emptyInfo: "Немає елементів для відображення",
	loadFailInfo: "Не вдалося завантажити оновлення",
	loadMore: "Завантажити ще",
	loadMoreLoading: "Завантаження...",
	loadPrevious: "Завантажити попередні",
	loadPreviousLoading: "Завантаження...",

//FilterBar
	"clearFilterDialogTitle": "Очистити фільтр",
	"filterDefDialogTitle": "Фільтр",
	"defaultRuleTitle": "Правило",
	"ruleTitleTemplate": "Правило ${ruleNumber}",
	"noFilterApplied": "Фільтри не використовуються.",
	"defineFilter": "Визначити фільтр",
	"defineFilterAriaLabel": "Визначити фільтр: відкриває вікно фільтра для налаштування складних правил фільтрації. Кожне правило фільтра складається з стовпця, умови та значення. У вікні, що відкриється, буде активним поле значення.",
	"conditionEqual": "дорівнює",
	"conditionNotEqual": "не дорівнює",
	"conditionLess": "менше за",
	"conditionLessEqual": "менше або дорівнює",
	"conditionGreater": "більше за",
	"conditionGreaterEqual": "більше або дорівнює",
	"conditionContain": "містить",
	"conditionIs": "дорівнює",
	"conditionStartWith": "починається з",
	"conditionEndWith": "закінчується на",
	"conditionNotContain": "не містить",
	"conditionIsNot": "не дорівнює",
	"conditionNotStartWith": "не починається з",
	"conditionNotEndWith": "не закінчується на",
	"conditionBefore": "до",
	"conditionAfter": "після",
	"conditionRange": "діапазон",
	"conditionIsEmpty": "порожній",
	"conditionIsNotEmpty": "не порожній",
	"all": "всі",
	"any": "будь-яке",
	"relationAll": "всі правила",
	"waiRelAll": "Відповідає всім наступним правилам:",
	"relationAny": "Будь-яке правило",
	"waiRelAny": "Відповідає будь-якому з наступних правил:",
	"relationMsgFront": "Відповідає",
	"relationMsgTail": "",
	"and": "та",
	"or": "або",
	"addRuleButton": "Додати правило",
	"waiAddRuleButton": "Додати нове правило",
	"removeRuleButton": "Видалити правило",
	"waiRemoveRuleButtonTemplate": "Видалити правило ${0}",
	"addRuleButton": "Додати правило фільтрації",
	"cancelButton": "Скасувати",
	"waiCancelButton": "Скасувати це вікно",
	"clearButton": "Очистити",
	"waiClearButton": "Очистити фільтр",
	"filterButton": "Фільтр",
	"waiFilterButton": "Застосувати фільтр",
	"columnSelectLabel": "Стовпець:",
	"columnSelectAriaLabel": "Стовпець: частина умови ${0} з ${1}",
	"waiColumnSelectTemplate": "Стовпчик для правила ${0}",

	"conditionSelectLabel": "Умова:",
	"conditionSelectAriaLabel": "Оператор: частина умови ${0} з ${1}",
	"waiConditionSelectTemplate": "Умова правила ${0}",

	"valueBoxLabel": "Значення:",
	"valueBoxAriaLabel": "Значення: частина умови ${0} з ${1}",
	"waiValueBoxTemplate": "Введіть значення для фільтрації за правилом ${0}",
	"rangeTo": "до",
	"rangeTemplate": "з ${0} до ${1}",
	"statusTipHeaderColumn": "Стовпчик",
	"statusTipHeaderCondition": "Правила",
	"statusTipTitle": "Панель фільтрів",
	"statusTipMsg": "Клацніть на панелі фільтрів для фільтрації за значеннями у ${0}.",
	"anycolumn": "будь-який стовпець",
	"statusTipTitleNoFilter": "Панель фільтрів",
	"statusTipTitleHasFilter": "Фільтр",
	"statusTipRelPre": "Відповідає",
	"statusTipRelPost": "правила.",
	"statusTipHeaderAll": "Відповідає всім правилам.",
	"statusTipHeaderAny": "Відповідає хоча б одному правилу.",
	"defaultItemsName": "елементи",
	"filterBarMsgHasFilterTemplate": "Показано ${0} з ${1} ${2}.",
	"filterBarMsgNoFilterTemplate": "Фільтр не використовується",
	"filterBarDefButton": "Визначити фільтр",
	"waiFilterBarDefButton": "Фільтрувати таблицю",
	"a11yFilterBarDefButton": "Фільтр...",
	"filterBarClearButton": "Очистити фільтр",
	"waiFilterBarClearButton": "Очистити фільтр",
	"closeFilterBarBtn": "Закрити панель фільтрів",
	"clearFilterMsg": "Ця опція видаляє фільтр та показує всі доступні записи.",
	"anyColumnOption": "Будь-який стовпець",
	"trueLabel": "Істина",
	"falseLabel": "Неправда",
	"radioTrueLabel": "Значення True",
	"radioFalseLabel": "Значення False",
	"beginTimeRangeLabel": "Початкове значення діапазону часу",
	"endTimeRangeLabel": "Кінцеве значення діапазону часу",
	"beginDateRangeLabel": "Початкове значення діапазону дат",
	"endDateRangeLabel": "Кінцеве значення діапазону дат",
	"startsWithExpr": "${0}*",

//NestedSort
	singleSort: "Однорівневе сортування",
	nestedSort: "Вкладене сортування",
	ascending: "Клацніть для сортування за зростанням",
	descending: "Клацніть для сортування за спаданням",
	sortingState: "${0} - ${1}",
	unsorted: "Не сортувати цей стовпець",
	waiSingleSortLabel: "${0} - відсортовано за ${1}. Виберіть для сортування за ${2}",
	waiNestedSortLabel:"${0} - вкладене сортування за ${1}. Виберіть для вкладеного сортування за ${2}",

//PaginationBar
	pagerWai: 'Пейджер',

	pageIndex: '${0}',
	pageIndexTitle: 'Сторінка ${0}',

	firstPageTitle: 'Перша сторінка',
	prevPageTitle: 'Попередня сторінка',
	nextPageTitle: 'Наступна сторінка',
	lastPageTitle: 'Остання сторінка',

	pageSize: '${0}',
	pageSizeTitle: '${0} елементів на сторінці',
	pageSizeAll: 'Всі',
	pageSizeAllTitle: 'Усі елементи',

	description: '${0} - ${1} з ${2} елементів.',
	descriptionEmpty: 'Матриця порожня.',

	summary: 'Всього: ${0}',
	summaryWithSelection: 'Всього: ${0} Вибрано: ${1}',

	gotoBtnTitle: 'Перейти до вказаної сторінки',

	gotoDialogTitle: 'Перейти до сторінки',
	gotoDialogMainMsg: 'Вкажіть номер сторінки:',
	gotoDialogPageCount: '(${0} сторінок)',
	gotoDialogOKBtn: 'Перейти',
	gotoDialogCancelBtn: 'Скасувати',
	// for drop down pagination bar
	pageLabel: 'Сторінка',
	pageSizeLabel: 'Рядки',

//QuickFilter
	filterLabel: 'Фільтр',
	clearButtonTitle: 'Очистити фільтр',
	buildFilterMenuLabel: 'Визначити фільтр…',
	apply: 'Застосувати фільтр',

//Sort
	helpMsg: '${0} - Клацніть для сортування або клацніть, утримуючи клавішу Control, для додання до списку сортування',
	singleHelpMsg: '${0} - Клацніть для сортування',
	priorityOrder: 'Пріоритет сортування: ${0}',

//SummaryBar
	summaryTotal: 'Всього: ${0}',
	summarySelected: 'Вибрано: ${0}',
	summaryRange: 'Діапазон: ${0}-${1}',	//need translation

//Other
	indirectSelectAll: "Натисніть клавішу Пробіл, щоб вибрати всі елементи. ",	//need translation
	indirectDeselectAll: "Натисніть клавішу Пробіл, щоб скасувати вибір всіх елементів. ",	//need translation
	treeExpanded: "Натисніть Control + стрілка вліво для згортання рядка.",	//need translation
	treeCollapsed: "Натисніть Control + стрілка вправо для розгортання рядка."	//need translation
});
